You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:05:21 UTC

svn commit: r1591058 [8/15] - in /openoffice/trunk/main: ./ accessibility/bridge/org/openoffice/java/accessibility/ accessibility/bridge/source/java/ accessibility/inc/accessibility/extended/ accessibility/inc/accessibility/standard/ accessibility/sour...

Modified: openoffice/trunk/main/filter/inc/filter/msfilter/mscodec.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/inc/filter/msfilter/mscodec.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/inc/filter/msfilter/mscodec.hxx (original)
+++ openoffice/trunk/main/filter/inc/filter/msfilter/mscodec.hxx Tue Apr 29 19:05:05 2014
@@ -279,7 +279,7 @@ public:
             Size of the destination buffer.
 
         @return
-            true = Encoding was successful (no error occured).
+            true = Encoding was successful (no error occurred).
     */
     bool                Encode(
                             const void* pData, sal_Size nDatLen,
@@ -305,7 +305,7 @@ public:
             Size of the destination buffer.
 
         @return
-            true = Decoding was successful (no error occured).
+            true = Decoding was successful (no error occurred).
     */
     bool                Decode(
                             const void* pData, sal_Size nDatLen,

Modified: openoffice/trunk/main/filter/inc/filter/msfilter/msocximex.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/inc/filter/msfilter/msocximex.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/inc/filter/msfilter/msocximex.hxx (original)
+++ openoffice/trunk/main/filter/inc/filter/msfilter/msocximex.hxx Tue Apr 29 19:05:05 2014
@@ -133,13 +133,13 @@ public:
 		com::sun::star::drawing::XShape >* /*pShape*/,
 		sal_Bool /*bFloatingCtrl*/ ) {return sal_False;}
 
-	/*begin: Backwards compatability with office 95 import, modify later*/
+	/*begin: Backwards compatibility with office 95 import, modify later*/
 	const com::sun::star::uno::Reference<
 		com::sun::star::lang::XMultiServiceFactory > & GetServiceFactory();
 
 	sal_uInt16 GetEditNum() { return ++nEdit; }
 	sal_uInt16 GetCheckboxNum() { return ++nCheckbox; }
-	/*end: Backwards compatability*/
+	/*end: Backwards compatibility*/
 protected:
 	const com::sun::star::uno::Reference< com::sun::star::drawing::XShapes > &
 		GetShapes();

Modified: openoffice/trunk/main/filter/inc/filter/msfilter/svxmsbas.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/inc/filter/msfilter/svxmsbas.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/inc/filter/msfilter/svxmsbas.hxx (original)
+++ openoffice/trunk/main/filter/inc/filter/msfilter/svxmsbas.hxx Tue Apr 29 19:05:05 2014
@@ -71,7 +71,7 @@ public:
 	sal_uLong SaveOrDelMSVBAStorage( sal_Bool bSaveInto, const String& rStorageName );
 
 	// check if the MS-VBA-Storage exist in the RootStorage of the DocShell.
-	// If it exist, then return the WarningId for loosing the information.
+	// If it exists, then return the WarningId for losing the information.
 	static sal_uLong GetSaveWarningOfMSVBAStorage( SfxObjectShell &rDocS );
 
 	static String GetMSBasicStorageName();

Modified: openoffice/trunk/main/filter/qa/complex/filter/detection/typeDetection/Helper.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/qa/complex/filter/detection/typeDetection/Helper.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/qa/complex/filter/detection/typeDetection/Helper.java (original)
+++ openoffice/trunk/main/filter/qa/complex/filter/detection/typeDetection/Helper.java Tue Apr 29 19:05:05 2014
@@ -139,13 +139,13 @@ public class Helper  {
              
              // example: data = "firstData;secondData;;forthData"
              // => three tokens => missing one data because the imagine 
-             // "thirdData" was not recieved by data.nextToken()
+             // "thirdData" was not received by data.nextToken()
              // Therefore here comes a special handling for empty datas
              boolean nextIsData = false;
              int dataCount = 0;
              while (data.hasMoreTokens()) {
                  Object myToken = data.nextToken();
-                 // if the "thirdData" will be recieved, myToken=";" but  
+                 // if the "thirdData" will be received, myToken=";" but  
                  // vData must add an empty String
                  if (myToken.equals(";")){
                      if (nextIsData ) {
@@ -371,7 +371,7 @@ public class Helper  {
 
     /**
      *  Filles the Hashtable m_hFileURLs with all file names and their URL
-     *  and the Hashtable m_hFilesTypes with all file names and thier file
+     *  and the Hashtable m_hFilesTypes with all file names and their file
      *  typ name. This informations are extracted from "files.csv"
      *  This is for faster acccess to get fileURL and fileType of fileAlias
      */

Modified: openoffice/trunk/main/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java (original)
+++ openoffice/trunk/main/filter/qa/complex/filter/misc/FinalizedMandatoryTest.java Tue Apr 29 19:05:05 2014
@@ -187,7 +187,7 @@ public class FinalizedMandatoryTest
                 // testobject must new created for every test. 
                 // We change in a loop the container and try to flush this changes.
                 // If we get an expected exception this container is corrupt. It's
-                // similar to a document which could not be saved beacuse of invalid
+                // similar to a document which could not be saved because of invalid
                 // contend. While you don't remove the invalid conted you will never
                 // be able to save the document. Same here.
                 try

Modified: openoffice/trunk/main/filter/source/config/cache/basecontainer.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/basecontainer.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/basecontainer.hxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/basecontainer.hxx Tue Apr 29 19:05:05 2014
@@ -60,7 +60,7 @@ namespace filter{
                 should be available etc.
 
     @attention  The base class BaseLock must be the first of declared ones.
-                Otherwhise we cant be shure, that our own mutex member (which is
+                Otherwise we can't be sure, that our own mutex member (which is
                 present by this base class!) was full initialized inside our own
                 ctor as first!
  */
@@ -97,7 +97,7 @@ class BaseContainer : public BaseLock
         /** @short  local filter cache, which is used to collect changes on the
                     filter configuration first and flush it later.
 
-            @descr  Normaly this member isnt used nor initialized. Thats true,
+            @descr  Normaly this member isn't used nor initialized. Thats true,
                     if this container is used for reading only. The first write access
                     (e.g. by calling insertByName()) creates a copy of the current
                     global cache m_rCache to initialize the m_pFlushCache member.
@@ -107,7 +107,7 @@ class BaseContainer : public BaseLock
 
                     m_pFlushCache and m_rCache must not be synchronized manually here.
                     m_rCache listen on the global configuration, where m_pFlushCache
-                    write its data. m_rCache update itself automaticly.
+                    write its data. m_rCache update itself automatically.
          */
         FilterCache* m_pFlushCache;
 
@@ -188,7 +188,7 @@ class BaseContainer : public BaseLock
         //---------------------------------------
 
         /** @short  check if the underlying configuration data was already loaded
-                    and do it if neccessary automaticly.
+                    and do it if necessary automatically.
          */
         void impl_loadOnDemand();
 
@@ -222,7 +222,7 @@ class BaseContainer : public BaseLock
                             FilterCache* p = impl_getWorkingCache();
                             p->doSomething();
                         aLock.clear();
-                        // after this point p cant b e guaranteed any longer!
+                        // after this point p can't b e guaranteed any longer!
          */
         FilterCache* impl_getWorkingCache() const;
 
@@ -291,7 +291,7 @@ class BaseContainer : public BaseLock
         //---------------------------------------
         // XContainerQuery
 
-        // must be implemented realy by derived class ...
+        // must be implemented really by derived class ...
         // We implement return of an empty result here only!
         // But we show an assertion :-)
         virtual css::uno::Reference< css::container::XEnumeration > SAL_CALL createSubSetEnumerationByQuery(const ::rtl::OUString& sQuery)

Modified: openoffice/trunk/main/filter/source/config/cache/cacheitem.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/cacheitem.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/cacheitem.hxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/cacheitem.hxx Tue Apr 29 19:05:05 2014
@@ -158,7 +158,7 @@ class CacheItem : public ::comphelper::S
 
             @param  sActLocale
                     must specify the current office locale.
-                    Its needed to adress the UIName property inside
+                    Its needed to address the UIName property inside
                     the list of possible ones.
          */
         void validateUINames(const ::rtl::OUString& sActLocale);
@@ -170,7 +170,7 @@ class CacheItem : public ::comphelper::S
                     
             @descr  Normaly the converter routines of the base class
                     SequenceAsHashMap do this job already.
-                    But it doesnt provide a "pack" mechanism to
+                    But it doesn't provide a "pack" mechanism to
                     ignore properties with empty (means "void") values.
 
             @return css::uno::Sequence< css::beans::PropertyValue >
@@ -199,9 +199,9 @@ typedef ::std::hash_map< ::rtl::OUString
             to an extension. Organization as an hash makes it
             faster then searching inside vectors.
 
-            On the other side e.g. URLPattern cant be realy adressed
+            On the other side e.g. URLPattern can't be really addressed
             by a hash value ... because the use wildcards. But
-            there we need key-value pairs too, which cant be provided
+            there we need key-value pairs too, which can't be provided
             by a pur vector!
  */
 typedef ::std::hash_map< ::rtl::OUString                    ,
@@ -217,7 +217,7 @@ typedef ::std::hash_map< ::rtl::OUString
     @descr  Every type in this list is combined with an information,
             which property matched to the given URL. The user of this
             structure can decide then, if a deep detection should be
-            supressed e.g. if an URLPattern was used.
+            suppressed e.g. if an URLPattern was used.
  */
 struct  FlatDetectionInfo
 {

Modified: openoffice/trunk/main/filter/source/config/cache/configflush.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/configflush.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/configflush.cxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/configflush.cxx Tue Apr 29 19:05:05 2014
@@ -122,7 +122,7 @@ void SAL_CALL ConfigFlush::refresh()
 void SAL_CALL ConfigFlush::addRefreshListener(const css::uno::Reference< css::util::XRefreshListener >& xListener)
     throw(css::uno::RuntimeException)
 {
-    // no locks neccessary
+    // no locks necessary
     // used helper lives if we live and is threadsafe by itself ...
     m_lListener.addInterface(::getCppuType(static_cast< css::uno::Reference< css::util::XRefreshListener >* >(NULL)),
                              xListener);
@@ -132,7 +132,7 @@ void SAL_CALL ConfigFlush::addRefreshLis
 void SAL_CALL ConfigFlush::removeRefreshListener(const css::uno::Reference< css::util::XRefreshListener >& xListener)
     throw(css::uno::RuntimeException)
 {
-    // no locks neccessary
+    // no locks necessary
     // used helper lives if we live and is threadsafe by itself ...
     m_lListener.removeInterface(::getCppuType(static_cast< css::uno::Reference< css::util::XRefreshListener >* >(NULL)),
                                 xListener);

Modified: openoffice/trunk/main/filter/source/config/cache/constant.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/constant.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/constant.hxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/constant.hxx Tue Apr 29 19:05:05 2014
@@ -96,7 +96,7 @@ extern rtl::OUString pFilterStrings[];
 #define  CFGSET_FRAMELOADERS        _FILTER_CONFIG_FROM_ASCII_("FrameLoaders"   )
 #define  CFGSET_CONTENTHANDLERS     _FILTER_CONFIG_FROM_ASCII_("ContentHandlers")
 
-/** @short  used to adress some configuration keys directly.
+/** @short  used to address some configuration keys directly.
 
     @descr  Such direct keys should be used with function
             FilterCache::impl_getDirectCFGValue() only!
@@ -181,7 +181,7 @@ extern rtl::OUString pFilterStrings[];
 #define  SERVICE_URLTRANSFORMER             _FILTER_CONFIG_FROM_ASCII_("com.sun.star.util.URLTransformer"                     )
 #define  SERVICE_FILTERCONFIGREFRESH        _FILTER_CONFIG_FROM_ASCII_("com.sun.star.document.FilterConfigRefresh"            )
 
-/** @short  some configuration pathes.
+/** @short  some configuration paths.
  */
 #define  CFGPACKAGE_TD_TYPES           _FILTER_CONFIG_FROM_ASCII_("/org.openoffice.TypeDetection.Types" )
 #define  CFGPACKAGE_TD_FILTERS         _FILTER_CONFIG_FROM_ASCII_("/org.openoffice.TypeDetection.Filter")

Modified: openoffice/trunk/main/filter/source/config/cache/contenthandlerfactory.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/contenthandlerfactory.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/contenthandlerfactory.cxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/contenthandlerfactory.cxx Tue Apr 29 19:05:05 2014
@@ -92,7 +92,7 @@ css::uno::Reference< css::uno::XInterfac
     #ifdef _FILTER_CONFIG_MIGRATION_Q_
 
         /* -> TODO - HACK
-            check if the given handler name realy exist ...
+            check if the given handler name really exists ...
             Because our old implementation worked with an internal
             type name instead of a handler name. For a small migration time
             we must simulate this old feature :-( */

Modified: openoffice/trunk/main/filter/source/config/cache/filtercache.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/filtercache.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/filterfactory.cxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/filterfactory.cxx Tue Apr 29 19:05:05 2014
@@ -135,7 +135,7 @@ css::uno::Reference< css::uno::XInterfac
     #ifdef _FILTER_CONFIG_MIGRATION_Q_
 
         /* -> TODO - HACK
-            check if the given filter name realy exist ...
+            check if the given filter name really exists ...
             Because our old implementation worked with an internal
             type name instead of a filter name. For a small migration time
             we must simulate this old feature :-( */
@@ -208,9 +208,9 @@ css::uno::Sequence< ::rtl::OUString > SA
     throw(css::uno::RuntimeException)
 {
     /* Attention: Instead of getElementNames() this method have to return only filter names,
-                  which can be created as UNO Services realy. Thats why we search for filters,
+                  which can be created as UNO Services really. Thats why we search for filters,
                   which dont have a valid value for the property "FilterService".
-                  Of course we cant check for corrupted service names here. We can check
+                  Of course we can't check for corrupted service names here. We can check
                   for empty strings only ...
     */
     CacheItem lIProps;
@@ -415,9 +415,9 @@ OUStringList FilterFactory::impl_queryMa
             const CacheItem                 aFilter = pCache->getItem(FilterCache::E_FILTER, sName);
                 CacheItem::const_iterator pProp   ;
 
-            // "matchByDocumentService="                    => any filter will be adressed here
-            // "matchByDocumentService=all"                 => any filter will be adressed here
-            // "matchByDocumentService=com.sun.star..."     => only filter matching this document service will be adressed
+            // "matchByDocumentService="                    => any filter will be addressed here
+            // "matchByDocumentService=all"                 => any filter will be addressed here
+            // "matchByDocumentService=com.sun.star..."     => only filter matching this document service will be addressed
             ::rtl::OUString sCheckValue = aFilter.getUnpackedValueOrDefault(PROPNAME_DOCUMENTSERVICE, ::rtl::OUString());
             if (
                 ( sDocumentService.getLength()                 ) &&
@@ -430,8 +430,8 @@ OUStringList FilterFactory::impl_queryMa
 
             // "iflags="        => not allowed
             // "iflags=-1"      => not allowed
-            // "iflags=0"       => not usefull
-            // "iflags=283648"  => only filter, which has set these flag field will be adressed
+            // "iflags=0"       => not useful
+            // "iflags=283648"  => only filter, which has set these flag field will be addressed
             sal_Int32 nCheckValue = aFilter.getUnpackedValueOrDefault(PROPNAME_FLAGS, (sal_Int32)0);
             if (
                 (nIFlags > 0                       ) &&
@@ -443,8 +443,8 @@ OUStringList FilterFactory::impl_queryMa
             
             // "eflags="        => not allowed
             // "eflags=-1"      => not allowed
-            // "eflags=0"       => not usefull
-            // "eflags=283648"  => only filter, which has not set these flag field will be adressed
+            // "eflags=0"       => not useful
+            // "eflags=283648"  => only filter, which has not set these flag field will be addressed
             if (
                 (nEFlags > 0                       ) &&
                 ((nCheckValue & nEFlags) == nEFlags)
@@ -674,7 +674,7 @@ OUStringList FilterFactory::impl_readSor
         xUISortConfig->getByName(sModule) >>= xModule;
         if (xModule.is()) // only to be on the safe side of life if the exception was not thrown .-)
         {
-            // Note: convertion of the returned Any to OUStringList throws
+            // Note: conversion of the returned Any to OUStringList throws
             // an IllegalArgumentException if the type does not match ...
             // but it resets the OUStringList to a length of 0 if the Any is empty!
             OUStringList lSortedFilters(xModule->getByName(PROPNAME_SORTEDFILTERLIST));

Modified: openoffice/trunk/main/filter/source/config/cache/frameloaderfactory.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/frameloaderfactory.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/frameloaderfactory.cxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/frameloaderfactory.cxx Tue Apr 29 19:05:05 2014
@@ -89,7 +89,7 @@ css::uno::Reference< css::uno::XInterfac
     #ifdef _FILTER_CONFIG_MIGRATION_Q_
 
         /* -> TODO - HACK
-            check if the given loader name realy exist ...
+            check if the given loader name really exists ...
             Because our old implementation worked with an internal
             type name instead of a loader name. For a small migration time
             we must simulate this old feature :-( */

Modified: openoffice/trunk/main/filter/source/config/cache/lateinitlistener.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/lateinitlistener.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/lateinitlistener.cxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/lateinitlistener.cxx Tue Apr 29 19:05:05 2014
@@ -119,7 +119,7 @@ void SAL_CALL LateInitListener::disposin
     // Normaly it should never be called. Because we cancel our listener connection
     // if we got the event about finished open of the first office document.
     // But if this method was reached, it indicates an office, which was started
-    // (might as remote script container for an external API client) but not realy used.
+    // (might as remote script container for an external API client) but not really used.
 
     // SAFE ->
     ::osl::ResettableMutexGuard aLock(m_aLock);

Modified: openoffice/trunk/main/filter/source/config/cache/querytokenizer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/querytokenizer.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/querytokenizer.hxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/querytokenizer.hxx Tue Apr 29 19:05:05 2014
@@ -53,7 +53,7 @@ namespace filter{
                 </ul>
                 uses this schema.
 
-    @attention  This class is not threadsafe implemented. Because its not neccessary.
+    @attention  This class is not threadsafe implemented. Because its not necessary.
                 But you have to make shure, that ist not used as such :-)
  */
 class QueryTokenizer : public ::std::hash_map< ::rtl::OUString                    ,
@@ -83,7 +83,7 @@ class QueryTokenizer : public ::std::has
                     a new query.
 
             @descr  The given query is immidiatly analyzed
-                    and seperated into its token, which can
+                    and separated into its token, which can
                     be access by some specialized method later.
 
             @param  sQuery

Modified: openoffice/trunk/main/filter/source/config/cache/typedetection.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/typedetection.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/typedetection.cxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/typedetection.cxx Tue Apr 29 19:05:05 2014
@@ -169,7 +169,7 @@ TypeDetection::~TypeDetection()
         // verify every flat detected (or preselected!) type
         // by calling its registered deep detection service.
         // But break this loop if a type match to the given descriptor
-        // by an URL pattern(!) or if deep detection isnt allowed from
+        // by an URL pattern(!) or if deep detection isn't allowed from
         // outside (bAllowDeep=sal_False) or break the whole detection by
         // throwing an exception if creation of the might needed input
         // stream failed by e.g. an IO exception ...
@@ -179,7 +179,7 @@ TypeDetection::~TypeDetection()
 
         //*******************************************
         // if no flat detected (nor preselected!) type could be
-        // verified and no error occured during creation of
+        // verified and no error occurred during creation of
         // the might needed input stream, start detection
         // which uses all registered deep detection services.
         if (
@@ -415,9 +415,9 @@ sal_Bool TypeDetection::impl_getPreselec
                                                     const css::util::URL&  aParsedURL ,
                                                           FlatDetection&   rFlatTypes )
 {
-    // Can be used to supress execution of some parts of this method
+    // Can be used to suppress execution of some parts of this method
     // if its already clear that detected type is valid or not.
-    // Its neccessary to use shared code at the end, which update
+    // Its necessary to use shared code at the end, which update
     // all return parameters constistency!
     sal_Bool bBreakDetection = sal_False;
 
@@ -456,7 +456,7 @@ sal_Bool TypeDetection::impl_getPreselec
 
     if (!bBreakDetection)
     {
-        // We cant check a preselected type for a given stream!
+        // We can't check a preselected type for a given stream!
         // So we must believe, that it can work ...
         if (aParsedURL.Complete.equalsAsciiL("private:stream", 14))
             bBreakDetection = sal_True;
@@ -471,8 +471,8 @@ sal_Bool TypeDetection::impl_getPreselec
                                                           INetURLObject::DECODE_WITH_CHARSET);
         sExtension = sExtension.toAsciiLowerCase();
 
-        // otherwhise we must know, if it matches to the given URL realy.
-        // especialy if it matches by its extension or pattern registration.
+        // otherwise we must know, if it matches to the given URL really.
+        // especially if it matches by its extension or pattern registration.
         OUStringList lExtensions(aType[PROPNAME_EXTENSIONS]);
         OUStringList lURLPattern(aType[PROPNAME_URLPATTERN]);
 
@@ -549,9 +549,9 @@ sal_Bool TypeDetection::impl_getPreselec
                                                       const css::util::URL&  aParsedURL   ,
                                                             FlatDetection&   rFlatTypes   )
 {
-    // Can be used to supress execution of some parts of this method
+    // Can be used to suppress execution of some parts of this method
     // if its already clear that detected filter is valid or not.
-    // Its neccessary to use shared code at the end, which update
+    // Its necessary to use shared code at the end, which update
     // all return parameters constistency!
     sal_Bool bBreakDetection = sal_False;
 
@@ -701,9 +701,9 @@ void TypeDetection::impl_getPreselection
         And the user normaly preselects a filter or type. The preslected
         document service cames from the dialog.
 
-        Further it doesnt matter if the user preselected a filter or a document service.
+        Further it doesn't matter if the user preselected a filter or a document service.
         A filter selection is always more explicit then a document service selection.
-        So it must be pereferred. An order between type and filter selection cant be discussed .-)
+        So it must be pereferred. An order between type and filter selection can't be discussed .-)
     */
 
     ::rtl::OUString sSelectedType = rDescriptor.getUnpackedValueOrDefault(::comphelper::MediaDescriptor::PROP_TYPENAME(), ::rtl::OUString());
@@ -737,8 +737,8 @@ void TypeDetection::impl_getPreselection
     // solutions:
     // a) no types                                => no detection
     // b) deep detection not allowed              => return first valid type of list (because its the preferred or the first valid one)
-    //    or(!) match by URLPattern               => in such case a deep detection will be supressed!
-    // c) type has no detect service              => safe the first occured type without a detect service
+    //    or(!) match by URLPattern               => in such case a deep detection will be suppressed!
+    // c) type has no detect service              => safe the first occurred type without a detect service
     //                                               as "last chance"(!). It will be used outside of this method
     //                                               if no further type could be detected.
     //                                               It must be the first one, because it can be a preferred type.
@@ -1005,7 +1005,7 @@ void TypeDetection::impl_seekStreamToZer
     // <- SAFE
 
     // Attention! If e.g. an office module was not installed sometimes we find a
-    // registered detect service, which is referred inside the configuration ... but not realy
+    // registered detect service, which is referred inside the configuration ... but not really
     // installed. On the other side we use third party components here, which can make trouble anyway.
     // So we should handle errors during creation of such services more gracefully .-)
     xDetector = css::uno::Reference< css::document::XExtendedFilterDetection >(
@@ -1087,8 +1087,8 @@ void TypeDetection::impl_seekStreamToZer
     // Dont distrub the user for "non existing files - means empty URLs" or
     // if we was forced to detect a stream.
     // Reason behind: We must be shure to ask user for "unknown contents" only ...
-    // and not for "missing files". Especialy if detection is done by a stream only
-    // we cant check if the stream points to an "existing content"!
+    // and not for "missing files". Especially if detection is done by a stream only
+    // we can't check if the stream points to an "existing content"!
     if (
         (!sURL.getLength()                                     ) || // "non existing file" ?
         (!xStream.is()                                         ) || // non existing file !

Modified: openoffice/trunk/main/filter/source/config/cache/typedetection.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/typedetection.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/typedetection.hxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/typedetection.hxx Tue Apr 29 19:05:05 2014
@@ -101,11 +101,11 @@ class TypeDetection : public ::cppu::Imp
                         MediaDescriptor and validate this information.
 
             @descr      Only in case the preselected filter exists and its type registration
-                        seems to be usefully, it would be used realy as valid type detection
-                        result. This method doesnt make any deep detection here. It checks only
+                        seems to be usefully, it would be used really as valid type detection
+                        result. This method doesn't make any deep detection here. It checks only
                         if the preselection match to the URL by an URLPattern.
                         This information has to be added to the given rFlatTypes list too.
-                        The outside code can use it to supress a deep detection then in general.
+                        The outside code can use it to suppress a deep detection then in general.
                         Because pattern are defined as non detectable at all!
 
             @param      pDescriptor
@@ -130,16 +130,16 @@ class TypeDetection : public ::cppu::Imp
             @descr      It steps over all flat detected types (given by the parameter lFlatTypes),
                         try it and search for most suitable one.
                         The specified MediaDescriptor will be patched, so it contain
-                        the right values everytime. Using of any deep detection service
+                        the right values every time. Using of any deep detection service
                         can be enabled/disabled. And last but not least: If the results
-                        wont be realy clear (because a flat detected type has no deep
+                        wont be really clear (because a flat detected type has no deep
                         detection service), a "sugested" type name will be returned as "rLastChance".
                         It can be used after e.g. all well known deep detection services
                         was used without getting any result. Then this "last-chance-type"
                         should be returned. Of course using of it can fail too ... but its a try :-)
 
                         As an optimization - this method collects the names of all used deep
-                        detection services. This information can be usefull inside the may be
+                        detection services. This information can be useful inside the may be
                         afterwards called method "impl_detectTypeDeepOnly()"!
 
             @param      rDescriptor
@@ -183,7 +183,7 @@ class TypeDetection : public ::cppu::Imp
                         and check her results. The first positive result will be
                         used for return. Its more a "try and error" algorithm then
                         a real type detection and will be used if a flat detection
-                        cant work realy ... e.g. if the extension of an URL is
+                        can't work really ... e.g. if the extension of an URL is
                         missing or wrong.
 
             @param      rDescriptor
@@ -207,7 +207,7 @@ class TypeDetection : public ::cppu::Imp
         /** @short      seek a might existing stream to position 0.
         
             @descr      This is an optinal action to be more robust
-                        in case any detect service doesnt make this seek ...
+                        in case any detect service doesn't make this seek ...
                         Normaly it's part of any called detect service or filter ...
                         but sometimes it's not done there.
 
@@ -222,7 +222,7 @@ class TypeDetection : public ::cppu::Imp
                         detect service (threadsafe!).
 
             @descr      It creates the right uno service, prepare the
-                        needed MediaDescriptor, call ths right interfaces,
+                        needed MediaDescriptor, call this right interfaces,
                         and return the results.
 
             @attention  The results (means type and corresponding filter)
@@ -258,7 +258,7 @@ class TypeDetection : public ::cppu::Imp
         //---------------------------------------
 
         /** @short      check if an input stream is already part of the
-                        given MediaDesciptor and creates a new one if neccessary.
+                        given MediaDesciptor and creates a new one if necessary.
 
             @attention  This method does further something special!
                         <ul>
@@ -286,7 +286,7 @@ class TypeDetection : public ::cppu::Imp
                         Note : Its content will be adapted to returned result of this method.
                         Means: The stream will be added to it.
 
-            @throw      Any suitable exception if stream should be opened but operation was not sucessfull.
+            @throw      Any suitable exception if stream should be opened but operation was not successful.
                         Note: If an interactionHandler is part of the given descriptor too, it was already used.
                         Means: let the exception pass trough the top most interface method!
          */
@@ -379,7 +379,7 @@ class TypeDetection : public ::cppu::Imp
                         types too !
 
             @note       #i60158#
-                        sometimes our text ascii and our csv filter cant work together.
+                        sometimes our text ascii and our csv filter can't work together.
                         Then we overwrite our detection hardly.
                         sType param is used as out parameter then too ... and
                         rDescriptor will be changed by selecting another filter.

Modified: openoffice/trunk/main/filter/source/config/cache/versions.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/versions.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/versions.hxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/versions.hxx Tue Apr 29 19:05:05 2014
@@ -27,6 +27,6 @@
 //_______________________________________________
 
 //#define _FILTER_CONFIG_Q_               // final Q code base
-#define _FILTER_CONFIG_MIGRATION_Q_     // usefull for migration time, to support some old functionality temp. :-)
+#define _FILTER_CONFIG_MIGRATION_Q_     // useful for migration time, to support some old functionality temp. :-)
 
 #endif // _FILTER_CONFIG_VERSIONS_HXX_

Modified: openoffice/trunk/main/filter/source/config/fragments/makefile.mk
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/fragments/makefile.mk?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/fragments/makefile.mk (original)
+++ openoffice/trunk/main/filter/source/config/fragments/makefile.mk Tue Apr 29 19:05:05 2014
@@ -156,7 +156,7 @@ PACKLANG_PARAM := --stringparam
 PACKLANG_XSL :=
 
 # -----------------------------------------------------------------------------
-# build every module seperated
+# build every module separated
 # -----------------------------------------------------------------------------
 
 $(REALFILTERPACKAGES_TYPES_FLAG) : $$(TYPES_4$$(@:b))

Modified: openoffice/trunk/main/filter/source/config/tools/merge/pyAltFCFGMerge
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/tools/merge/pyAltFCFGMerge?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/tools/merge/pyAltFCFGMerge (original)
+++ openoffice/trunk/main/filter/source/config/tools/merge/pyAltFCFGMerge Tue Apr 29 19:05:05 2014
@@ -311,7 +311,7 @@ def printHelp():
     print("parameters:")
     print("\tcfg=<file name>")
     print("\t\tmust point to a system file, which contains")
-    print("\t\tall neccessary configuration data for the merge process.")
+    print("\t\tall necessary configuration data for the merge process.")
     print("\tFurther cou can specify every parameter allowed in the")
     print("\tconfig file as command line parameter too, to overwrite")
     print("\tthe value from the file.")
@@ -502,7 +502,7 @@ class Merger:
                 self.m_aCfg.getValue(PROP_XMLPACKAGE ),\
                 self.m_aCfg.getValueWithDefault(PROP_LANGUAGEPACK, False))
 
-        # counts all transfered fragments
+        # counts all transferred fragments
         # Can be used later to decide, if a generated package file
         # contains "nothing"!
         nItemCount = 0

Modified: openoffice/trunk/main/filter/source/config/tools/split/FCFGSplit.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/tools/split/FCFGSplit.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/tools/split/FCFGSplit.java (original)
+++ openoffice/trunk/main/filter/source/config/tools/split/FCFGSplit.java Tue Apr 29 19:05:05 2014
@@ -182,7 +182,7 @@ public class FCFGSplit
      *  Its meaned relativ to m_sOutDir. */
     private static java.lang.String m_sSubDirContentHandlers;
 
-    /** enable/disable generating of filter groups - seperated by
+    /** enable/disable generating of filter groups - separated by
      *  application modules. */
     private static boolean m_bSeperateFiltersByModule;
 
@@ -466,7 +466,7 @@ public class FCFGSplit
         sTimes.append(" ms\n"                            );
         m_aDebug.setDetailedInfo(sTimes.toString());
 
-        // everyting seems to be ok.
+        // everything seems to be ok.
         // Return "OK" to calli.
         m_aDebug.setGlobalInfo("Finish.");
         System.exit(0);

Modified: openoffice/trunk/main/filter/source/config/tools/split/Splitter.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/tools/split/Splitter.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/tools/split/Splitter.java (original)
+++ openoffice/trunk/main/filter/source/config/tools/split/Splitter.java Tue Apr 29 19:05:05 2014
@@ -80,7 +80,7 @@ public class Splitter
         createDirectoryStructures();
 
         // use some statistic values to check if all cache items
-        // will be transformed realy.
+        // will be transformed really.
         int nTypes           = m_aDataSet.m_aCache.getItemCount(Cache.E_TYPE          );
         int nFilters         = m_aDataSet.m_aCache.getItemCount(Cache.E_FILTER        );
         int nDetectServices  = m_aDataSet.m_aCache.getItemCount(Cache.E_DETECTSERVICE );

Modified: openoffice/trunk/main/filter/source/flash/swfdialog.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/flash/swfdialog.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/flash/swfdialog.cxx (original)
+++ openoffice/trunk/main/filter/source/flash/swfdialog.cxx Tue Apr 29 19:05:05 2014
@@ -171,7 +171,7 @@ Dialog*	SWFDialog::createDialog( Window*
 
     if( mpResMgr && mxSrcDoc.is() )
     {
-/*		TODO: From the controler we may get information what page is visible and what shapes
+/*		TODO: From the controller we may get information what page is visible and what shapes
 			  are selected, if we optionaly want to limit output to that
         Any aSelection;
 

Modified: openoffice/trunk/main/filter/source/flash/swffilter.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/flash/swffilter.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/flash/swffilter.cxx (original)
+++ openoffice/trunk/main/filter/source/flash/swffilter.cxx Tue Apr 29 19:05:05 2014
@@ -211,7 +211,7 @@ OUString exportBackground(FlashExporter 
 	OUString filename = STR("slide") + VAL(nPage+1) + STR(suffix) + STR(".swf");
 	OUString fullpath = sPath + STR("/") + filename;
 
-	// AS: If suffix is "o" then the last paramter is true (for exporting objects).
+	// AS: If suffix is "o" then the last parameter is true (for exporting objects).
 	Reference<XOutputStream> xOutputStreamWrap(*(new OslOutputStreamWrapper(fullpath)), UNO_QUERY);
 	sal_uInt16 nCached = aFlashExporter.exportBackgrounds( xDrawPage, xOutputStreamWrap, sal::static_int_cast<sal_uInt16>( nPage ), *suffix == 'o' );
 	aFlashExporter.Flush();

Modified: openoffice/trunk/main/filter/source/flash/swfwriter.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/flash/swfwriter.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/flash/swfwriter.cxx (original)
+++ openoffice/trunk/main/filter/source/flash/swfwriter.cxx Tue Apr 29 19:05:05 2014
@@ -545,7 +545,7 @@ sal_Bool Writer::streamSound( const char
 // not the sum of the number of samples in the L and R channels.
 // 
 // The return code = number of bytes output in mp3buffer.  This can be 0.
-// If it is <0, an error occured.
+// If it is <0, an error occurred.
 
 
 		for (int samples_written = 0; samples_written < info.frames; samples_written += samples_per_frame)

Modified: openoffice/trunk/main/filter/source/flash/swfwriter1.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/flash/swfwriter1.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/flash/swfwriter1.cxx (original)
+++ openoffice/trunk/main/filter/source/flash/swfwriter1.cxx Tue Apr 29 19:05:05 2014
@@ -607,7 +607,7 @@ void Writer::Impl_writeText( const Point
 
 		// write text element
 
-/* test code to create a bound rect, not realy working for rotated text
+/* test code to create a bound rect, not really working for rotated text
 			Size		aTextSize( map( Size( mpVDev->GetTextWidth( rText ), mpVDev->GetTextHeight() ) ) );
 			Point		aMetricPoint( map( Point( aMetric.GetLeading(), aMetric.GetAscent() )  ) );
 
@@ -710,7 +710,7 @@ void Writer::Impl_writeText( const Point
 
 		maShapeIds.push_back( nTextId );
 
-		// AS: Write strikeout and underline, if neccessary.  This code was originally taken from the SVG
+		// AS: Write strikeout and underline, if necessary.  This code was originally taken from the SVG
 		//  export facility, although the positioning had to be tweaked a little.  I can't explain the
 		//  numbers, but the flash lines up very well with the original OOo document.  All of this should
 		//  probably be converted to polygons as part of the meta file, though, as we don't handle any
@@ -757,9 +757,9 @@ void Writer::Impl_writeText( const Point
 }
 
 // -----------------------------------------------------------------------------
-// AS: Because JPEGs require the alpha channel provided seperately (JPEG does not
-//  natively support alpha channel, but SWF lets you provide it seperately), we
-//  extract the alpha channel into a seperate array here.
+// AS: Because JPEGs require the alpha channel provided separately (JPEG does not
+//  natively support alpha channel, but SWF lets you provide it separately), we
+//  extract the alpha channel into a separate array here.
 void getBitmapData( const BitmapEx& aBmpEx, sal_uInt8*& tgadata, sal_uInt8*& tgaAlphadata, sal_uInt32& nWidth, sal_uInt32& nHeight )
 {
     if( !aBmpEx.IsEmpty() )
@@ -860,7 +860,7 @@ sal_uInt16 Writer::defineBitmap( const B
 #endif
 
 	// AS: SWF files let you provide an Alpha mask for JPEG images, but we have
-	//  to ZLIB compress the alpha channel seperately.
+	//  to ZLIB compress the alpha channel separately.
 	uLong alpha_compressed_size = 0;
 	sal_uInt8 *pAlphaCompressed = NULL;
 	if (bmpSource.IsAlpha() || bmpSource.IsTransparent())
@@ -1043,7 +1043,7 @@ void Writer::Impl_writeBmp( sal_uInt16 n
 
 void Writer::Impl_writeJPEG(sal_uInt16 nBitmapId, const sal_uInt8* pJpgData, sal_uInt32 nJpgDataLength, sal_uInt8 *pAlphaCompressed, sal_uInt32 alpha_compressed_size )
 {
-	// AS: Go through the actuall JPEG bits, seperating out the
+	// AS: Go through the actuall JPEG bits, separating out the
 	//  header fields from the actual image fields.  Fields are
 	//  identifed by 0xFFXX where XX is the field type.  Both
 	//  the header and the image need start and stop (D8 and D9),
@@ -1092,7 +1092,7 @@ void Writer::Impl_writeJPEG(sal_uInt16 n
 			nLength = 2 + (pJpgSearch[2]<<8) + pJpgSearch[3];
 		}
 
-		// AS: I'm refering to libjpeg for a list of what these
+		// AS: I'm referring to libjpeg for a list of what these
 		//  markers are.  See jdmarker.c for a list.
 		// AS: I'm ignoring application specific markers 0xE1...0xEF
 		//  and comments 0xFE.  I don't know what

Modified: openoffice/trunk/main/filter/source/graphicfilter/ieps/ieps.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/graphicfilter/ieps/ieps.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/graphicfilter/ieps/ieps.cxx (original)
+++ openoffice/trunk/main/filter/source/graphicfilter/ieps/ieps.cxx Tue Apr 29 19:05:05 2014
@@ -173,7 +173,7 @@ static oslProcessError runProcessWithPat
      *
      * Because one of our programs is called "convert" and there is a convert
      * in the windows system directory, we want to explicitly search the PATH
-     * to avoid picking up on that one if ImageMagick's convert preceeds it in
+     * to avoid picking up on that one if ImageMagick's convert precedes it in
      * PATH.
      *
      */

Modified: openoffice/trunk/main/filter/source/msfilter/countryid.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/msfilter/countryid.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/msfilter/countryid.cxx (original)
+++ openoffice/trunk/main/filter/source/msfilter/countryid.cxx Tue Apr 29 19:05:05 2014
@@ -325,7 +325,7 @@ CountryId ConvertLanguageToCountry( Lang
 
 LanguageType ConvertCountryToLanguage( CountryId eCountry )
 {
-    // just find the first occurance of eCountry and return the language type
+    // just find the first occurrence of eCountry and return the language type
     const CountryEntry* pEntry = std::find_if( pTable, pEnd, CountryEntryPred_Country( eCountry ) );
     return (pEntry != pEnd) ? pEntry->meLanguage : LANGUAGE_DONTKNOW;
 }

Modified: openoffice/trunk/main/filter/source/msfilter/dffpropset.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/msfilter/dffpropset.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/msfilter/dffpropset.cxx (original)
+++ openoffice/trunk/main/filter/source/msfilter/dffpropset.cxx Tue Apr 29 19:05:05 2014
@@ -1131,7 +1131,7 @@ void DffPropSet::ReadPropSet( SvStream& 
 				sal_uInt32 nMergeFlags = nContent;
 
 				nMergeFlags &=  ( nMergeFlags >> 16 ) | 0xffff0000;				// clearing low word
-				nMergeFlags &= ( ( nCurrentFlags & 0xffff0000 )					// remove allready hard set
+				nMergeFlags &= ( ( nCurrentFlags & 0xffff0000 )					// remove already hard set
 								| ( nCurrentFlags >> 16 ) ) ^ 0xffffffff;		// attributes from mergeflags
 				nCurrentFlags &= ( ( nMergeFlags & 0xffff0000 )					// apply zero master bits
 								| ( nMergeFlags >> 16 ) ) ^ 0xffffffff;

Modified: openoffice/trunk/main/filter/source/msfilter/msdffimp.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/msfilter/msdffimp.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/msfilter/msdffimp.cxx (original)
+++ openoffice/trunk/main/filter/source/msfilter/msdffimp.cxx Tue Apr 29 19:05:05 2014
@@ -3379,7 +3379,7 @@ FASTBOOL SvxMSDffManager::SeekToRec( SvS
 	}
 	while ( rSt.GetError() == 0 && rSt.Tell() < nMaxFilePos && !bRet );
 	if ( !bRet )
-		rSt.Seek( nFPosMerk );	// restore orginal FilePos
+		rSt.Seek( nFPosMerk );	// restore original FilePos
 	return bRet;
 }
 
@@ -3620,7 +3620,7 @@ Color SvxMSDffManager::MSO_CLR_ToColor( 
 					aColor = Color( (sal_uInt8)nR, (sal_uInt8)nG, (sal_uInt8)nB );
 				}
 				break;
-				case 0x04 :		// substract grey level RGB(p,p,p)
+				case 0x04 :		// subtract grey level RGB(p,p,p)
 				{
 					sal_Int16 nR = (sal_Int16)aColor.GetRed() - (sal_Int16)nParameter;
 					sal_Int16 nG = (sal_Int16)aColor.GetGreen() - (sal_Int16)nParameter;
@@ -3634,7 +3634,7 @@ Color SvxMSDffManager::MSO_CLR_ToColor( 
 					aColor = Color( (sal_uInt8)nR, (sal_uInt8)nG, (sal_uInt8)nB );
 				}
 				break;
-				case 0x05 :		// substract from grey level RGB(p,p,p)
+				case 0x05 :		// subtract from grey level RGB(p,p,p)
 				{
 					sal_Int16 nR = (sal_Int16)nParameter - (sal_Int16)aColor.GetRed();
 					sal_Int16 nG = (sal_Int16)nParameter - (sal_Int16)aColor.GetGreen();
--- openoffice/trunk/main/filter/source/config/cache/basecontainer.cxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/basecontainer.cxx Tue Apr 29 19:05:05 2014
@@ -61,7 +61,7 @@ BaseContainer::BaseContainer()
     m_rCache->load(FilterCache::E_CONTAINS_STANDARD);
 
     // GLOBAL SAFE (!) -> -----------------------
     // TODO use rtl pattern to create it realy threadsafe!
     ::osl::ResettableMutexGuard aGlobalLock(::osl::Mutex::getGlobalMutex());
     if (!m_pPerformanceOptimizer)
         m_pPerformanceOptimizer = new ::salhelper::SingletonRef< FilterCache >();
@@ -107,7 +107,7 @@ void BaseContainer::impl_loadOnDemand()
     ::osl::ResettableMutexGuard aLock(m_aLock);
 
     // A generic container needs all items of a set of our cache!
     // Of course it can block for a while, till the cache is realy filled.
     // Note: dont load all sets supported by the cache here!
 
     FilterCache::EFillState eRequiredState = FilterCache::E_CONTAINS_NOTHING;
@@ -151,7 +151,7 @@ void BaseContainer::impl_initFlushMode()
         m_pFlushCache = m_rCache->clone();
     if (!m_pFlushCache)
         throw css::uno::RuntimeException(
-                ::rtl::OUString::createFromAscii("Cant create write copy of internal used cache on demand."),
+                ::rtl::OUString::createFromAscii("Can't create write copy of internal used cache on demand."),
                 dynamic_cast< css::container::XNameAccess* >(this));
     // <- SAFE
 }
@@ -274,7 +274,7 @@ void SAL_CALL BaseContainer::removeByNam
     impl_initFlushMode();
 
     FilterCache* pCache = impl_getWorkingCache();
-    pCache->removeItem(m_eType, sItem); // throw exceptions automaticly
+    pCache->removeItem(m_eType, sItem); // throw exceptions automatically
 
     aLock.clear();
     // <- SAFE ----------------------------------
@@ -333,7 +333,7 @@ css::uno::Any SAL_CALL BaseContainer::ge
 {
     if (!sItem.getLength())
         throw css::container::NoSuchElementException(
-                ::rtl::OUString::createFromAscii("An empty item cant be part of this cache!"),
+                ::rtl::OUString::createFromAscii("An empty item can't be part of this cache!"),
                 css::uno::Reference< css::uno::XInterface >(static_cast< css::container::XNameAccess* >(this), css::uno::UNO_QUERY));
 
     css::uno::Any aValue;
@@ -431,7 +431,7 @@ sal_Bool SAL_CALL BaseContainer::hasByNa
 css::uno::Type SAL_CALL BaseContainer::getElementType()
     throw (css::uno::RuntimeException)
 {
-    // no lock neccessary - because the type of our items
+    // no lock necessary - because the type of our items
     // is fix! no internal call or member needed ...
     return ::getCppuType(static_cast< css::uno::Sequence< css::beans::PropertyValue >* >(NULL));
 }
@@ -471,7 +471,7 @@ sal_Bool SAL_CALL BaseContainer::hasElem
 css::uno::Reference< css::container::XEnumeration > SAL_CALL BaseContainer::createSubSetEnumerationByQuery(const ::rtl::OUString& /* sQuery */ )
     throw (css::uno::RuntimeException)
 {
-    OSL_ENSURE(sal_False, "not pure virtual ... but not realy implemented .-)");
+    OSL_ENSURE(sal_False, "not pure virtual ... but not really implemented .-)");
 
     ::comphelper::OEnumerationByName* pEnum = new ::comphelper::OEnumerationByName(this, css::uno::Sequence< ::rtl::OUString >());
     return css::uno::Reference< css::container::XEnumeration >(static_cast< css::container::XEnumeration* >(pEnum), css::uno::UNO_QUERY);
@@ -505,7 +505,7 @@ css::uno::Reference< css::container::XEn
     catch(const css::uno::Exception&)
     {
         // invalid cache, internal failure, wrong conversion ...!?
-        // doesnt matter
+        // doesn't matter
         lKeys.clear();
     }
 
@@ -538,7 +538,7 @@ void SAL_CALL BaseContainer::flush()
 
     if (!m_pFlushCache)
         throw css::lang::WrappedTargetRuntimeException(
-                ::rtl::OUString::createFromAscii("Cant guarantee cache consistency. Special flush container does not exists!"),
+                ::rtl::OUString::createFromAscii("Can't guarantee cache consistency. Special flush container does not exists!"),
                 dynamic_cast< css::container::XNameAccess* >(this),
                 css::uno::Any());
 
@@ -612,7 +612,7 @@ void SAL_CALL BaseContainer::flush()
 void SAL_CALL BaseContainer::addFlushListener(const css::uno::Reference< css::util::XFlushListener >& xListener)
     throw (css::uno::RuntimeException)
 {
-    // no locks neccessary
+    // no locks necessary
     // used helper lives if we live and is threadsafe by itself ...
     m_lListener.addInterface(::getCppuType(static_cast< css::uno::Reference< css::util::XFlushListener >* >(NULL)),
                              xListener                                                                           );
@@ -624,7 +624,7 @@ void SAL_CALL BaseContainer::addFlushLis
 void SAL_CALL BaseContainer::removeFlushListener(const css::uno::Reference< css::util::XFlushListener >& xListener)
     throw (css::uno::RuntimeException)
 {
-    // no locks neccessary
+    // no locks necessary
     // used helper lives if we live and is threadsafe by itself ...
     m_lListener.removeInterface(::getCppuType(static_cast< css::uno::Reference< css::util::XFlushListener >* >(NULL)),
                                 xListener                                                                           );
@@ -61,7 +61,7 @@ BaseContainer::BaseContainer()
 
     // GLOBAL SAFE (!) -> -----------------------
-    // TODO use rtl pattern to create it realy threadsafe!
+    // TODO use rtl pattern to create it really threadsafe!
     ::osl::ResettableMutexGuard aGlobalLock(::osl::Mutex::getGlobalMutex());
     if (!m_pPerformanceOptimizer)
@@ -107,7 +107,7 @@ void BaseContainer::impl_loadOnDemand()
 
     // A generic container needs all items of a set of our cache!
-    // Of course it can block for a while, till the cache is realy filled.
+    // Of course it can block for a while, till the cache is really filled.
     // Note: dont load all sets supported by the cache here!
 

Modified: openoffice/trunk/main/filter/source/config/cache/basecontainer.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/basecontainer.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/filtercache.cxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/filtercache.cxx Tue Apr 29 19:05:05 2014
@@ -186,7 +186,7 @@ void FilterCache::takeOver(const FilterC
     m_eFillState     = rClone.m_eFillState;
 
 	// renew all dependencies and optimizations
-	// Because we cant be shure, that changed filters on one clone
+	// Because we can't be sure, that changed filters on one clone
 	// and changed types of another clone work together.
 	// But here we can check against the lates changes ...
     impl_validateAndOptimize();
@@ -222,7 +222,7 @@ void FilterCache::load(EFillState eRequi
         )
        )
     {
-        OSL_ENSURE(sal_False, "Who disturb our \"fill cache on demand\" feature and force loading of ALL data during office startup? Please optimize your code, so a full filled filter cache is not realy needed here!");
+        OSL_ENSURE(sal_False, "Who disturbs our \"fill cache on demand\" feature and force loading of ALL data during office startup? Please optimize your code, so a full filled filter cache is not really needed here!");
     }
 #endif
 
@@ -429,14 +429,14 @@ CacheItem FilterCache::getItem(      EIt
     {
         // ... or load it on demand from the
         // underlying configuration layer.
         // Note: NoSuchElementException is thrown automaticly here if
         // item could not be loaded!
         pIt = impl_loadItemOnDemand(eType, sItem);
     }
 
     /* Workaround for #137955#
        Draw types and filters are installed ... but draw was disabled during setup.
-       We must supress accessing these filters. Otherwise the office can crash.
+       We must suppress accessing these filters. Otherwise the office can crash.
        Solution for the next major release: do not install those filters !
      */
     if (eType == E_FILTER)
@@ -456,7 +456,7 @@ CacheItem FilterCache::getItem(      EIt
             ::rtl::OUStringBuffer sMsg(256);
             sMsg.appendAscii("The requested filter '"                                                               );
             sMsg.append     (sItem                                                                                  );
-            sMsg.appendAscii("' exists ... but it shouldnt; because the corresponding OOo module was not installed.");
+            sMsg.appendAscii("' exists ... but it shouldn't; because the corresponding OOo module was not installed.");
             throw css::container::NoSuchElementException(sMsg.makeStringAndClear(), css::uno::Reference< css::uno::XInterface >());
         }
     }
@@ -505,13 +505,13 @@ void FilterCache::setItem(      EItemTyp
     CacheItemList& rList = impl_getItemList(eType);
 
     // name must be part of the property set too ... otherwhise our
-    // container query cant work correctly
+    // container query can't work correctly
     CacheItem aItem = aValue;
     aItem[PROPNAME_NAME] <<= sItem;
     aItem.validateUINames(m_sActLocale);
 
 	// remove implicit properties as e.g. FINALIZED or MANDATORY
-	// They cant be saved here and must be readed on demand later, if they are needed.
+	// They can't be saved here and must be readed on demand later, if they are needed.
 	removeStatePropsFromItem(aItem);
 
     rList[sItem] = aItem;
@@ -564,8 +564,8 @@ void FilterCache::addStatePropsToItem(  
 			{
 				/* TODO
 					Hack -->
-						The default frame loader cant be located inside te normal set of frame loaders.
-						Its an atomic property inside the misc cfg package. So we cant retrieve the information
+						The default frame loader can't be located inside te normal set of frame loaders.
+						Its an atomic property inside the misc cfg package. So we can't retrieve the information
 						about FINALIZED and MANDATORY very easy ... :-(
 						=> set it to readonly/required everytimes :-)
 				*/
@@ -615,8 +615,8 @@ void FilterCache::addStatePropsToItem(  
 			May by the following reason exists:
 				-	The item does not exists inside the new configuration package org.openoffice.TypeDetection - but
 					we got it from the old package org.openoffice.Office/TypeDetection. We dont migrate such items
-					automaticly to the new format. Because it will disturb e.g. the deinstallation of an external filter
-					package. Because such external filter can remove the old file - but not the automaticly created new one ...
+					automatically to the new format. Because it will disturb e.g. the deinstallation of an external filter
+					package. Because such external filter can remove the old file - but not the automatically created new one ...
 
 			=> mark item as FINALIZED / MANDATORY, we dont support writing to the old format
 		*/
@@ -715,7 +715,7 @@ void FilterCache::impl_flushByList(const
 				// special case. no exception - but not a valid item => set must be finalized or mandatory!
 				// Reject flush operation by throwing an exception. At least one item couldnt be flushed.
 				if (!xItem.is())
-					throw css::uno::Exception(::rtl::OUString::createFromAscii("Cant add item. Set is finalized or mandatory!"),
+					throw css::uno::Exception(::rtl::OUString::createFromAscii("Can't add item. Set is finalized or mandatory!"),
 											  css::uno::Reference< css::uno::XInterface >()									  );
 
                 CacheItemList::const_iterator pItem = rCache.find(sItem);
@@ -732,7 +732,7 @@ void FilterCache::impl_flushByList(const
 				// special case. no exception - but not a valid item => it must be finalized or mandatory!
 				// Reject flush operation by throwing an exception. At least one item couldnt be flushed.
 				if (!xItem.is())
-					throw css::uno::Exception(::rtl::OUString::createFromAscii("Cant change item. Its finalized or mandatory!"),
+					throw css::uno::Exception(::rtl::OUString::createFromAscii("Can't change item. Its finalized or mandatory!"),
 											  css::uno::Reference< css::uno::XInterface >()									   );
 
                 CacheItemList::const_iterator pItem = rCache.find(sItem);
@@ -767,7 +767,7 @@ void FilterCache::detectFlatForURL(const
     // i) Step over all well known URL pattern
     //    and add registered types to the return list too
     //    Do it as first one - because: if a type match by a
-    //    pattern a following deep detection can be supressed!
+    //    pattern a following deep detection can be suppressed!
     //    Further we can stop after first match ...
     for (CacheItemRegistration::const_iterator pPattReg  = m_lURLPattern2Types.begin();
                                                pPattReg != m_lURLPattern2Types.end()  ;
@@ -899,7 +899,7 @@ css::uno::Reference< css::uno::XInterfac
         }
         break;
 
-        default : throw css::uno::Exception(::rtl::OUString::createFromAscii("These configuration node isnt supported here for open!"), 0);
+        default : throw css::uno::Exception(::rtl::OUString::createFromAscii("These configuration node isn't supported here for open!"), 0);
     }
 
     {
@@ -1074,7 +1074,7 @@ void FilterCache::impl_validateAndOptimi
     }
 
     // Create a log for all detected problems, which
-    // occure in the next feew lines.
+    // occur in the next feew lines.
     // If there are some real errors throw a RuntimException!
     // If there are some warnings only, show an assertion.
     sal_Int32             nErrors   = 0;
@@ -1095,7 +1095,7 @@ void FilterCache::impl_validateAndOptimi
             impl_resolveItem4TypeRegistration(&m_lDetectServices, sDetectService, sType);
 
         // get its registration for file Extensions AND(!) URLPattern ...
-        // It doesnt matter if these items exists or if our
+        // It doesn't matter if these items exists or if our
         // used index access create some default ones ...
         // only in case there is no filled set of Extensions AND
         // no filled set of URLPattern -> we must try to remove this invalid item
@@ -1134,8 +1134,8 @@ void FilterCache::impl_validateAndOptimi
         // its set list of extensions/url pattern. If its a "normal" type
         // set it at the end of this optimized list. But if its
         // a "Preferred" one - set it to the front of this list.
         // Of course multiple "Preferred" registrations can occure
         // (they shouldnt - but they can!) ... Ignore it. The last
         // preferred type is useable in the same manner then every
         // other type!
         sal_Bool bPreferred = sal_False;
@@ -1144,7 +1144,7 @@ void FilterCache::impl_validateAndOptimi
         const ::rtl::OUString* pExtensions = lExtensions.getConstArray();
         for (sal_Int32 e=0; e<ce; ++e)
         {
-            // Note: We must be shure that adress the right hash entry
+            // Note: We must be sure that address the right hash entry
             // does not depend from any upper/lower case problems ...
             ::rtl::OUString sNormalizedExtension = pExtensions[e].toAsciiLowerCase();
 
@@ -1176,7 +1176,7 @@ void FilterCache::impl_validateAndOptimi
         // Dont check cross references between types and filters, if
         // not all filters read from disk!
         // OK - this cache can read single filters on demand too ...
         // but then the fill state of this cache shouldnt be set to E_CONTAINS_FILTERS!
         if (!bAllFiltersShouldExist)
             continue;
 
@@ -1204,7 +1204,7 @@ void FilterCache::impl_validateAndOptimi
                 sLog.appendAscii("Warning\t:\t"                                            );
                 sLog.appendAscii("The type \""                                             );
                 sLog.append     (sType                                                     );
-                sLog.appendAscii("\" isnt used by any filter, loader or content handler.\n");
+                sLog.appendAscii("\" isn't used by any filter, loader or content handler.\n");
                 ++nWarnings;
             }
         }
@@ -1391,7 +1391,7 @@ FilterCache::EItemFlushState FilterCache
 
     EItemFlushState eState( E_ITEM_UNCHANGED );
 
-    // !? ... such situation can occure, if an item was added and(!) removed before it was flushed :-)
+    // !? ... such situation can occur, if an item was added and(!) removed before it was flushed :-)
     if (!bExistsInConfigLayer && !bExistsInMemory)
         eState = E_ITEM_UNCHANGED;
     else
@@ -1416,7 +1416,7 @@ void FilterCache::impl_resolveItem4TypeR
     throw(css::uno::Exception)
 {
     CacheItem& rItem = (*pList)[sItem];
     // In case its a new created entry (automaticly done by the hash_map index operator!)
     // we must be shure, that this entry has its own name as property available.
     // Its needed later at our container interface!
     rItem[PROPNAME_NAME] <<= sItem;
@@ -1449,7 +1449,7 @@ void FilterCache::impl_load(EFillState e
        )
     {
         // Attention! If config couldnt be opened successfully
         // and exception os thrown automaticly and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xTypes(impl_openConfig(E_PROVIDER_TYPES), css::uno::UNO_QUERY);
         {
@@ -1466,7 +1466,7 @@ void FilterCache::impl_load(EFillState e
        )
     {
         // Attention! If config couldnt be opened successfully
         // and exception os thrown automaticly and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xTypes(impl_openConfig(E_PROVIDER_TYPES), css::uno::UNO_QUERY);
         {
@@ -1483,7 +1483,7 @@ void FilterCache::impl_load(EFillState e
        )
     {
         // Attention! If config couldnt be opened successfully
         // and exception os thrown automaticly and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xFilters(impl_openConfig(E_PROVIDER_FILTERS), css::uno::UNO_QUERY);
         {
@@ -1500,7 +1500,7 @@ void FilterCache::impl_load(EFillState e
        )
     {
         // Attention! If config couldnt be opened successfully
         // and exception os thrown automaticly and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xLoaders(impl_openConfig(E_PROVIDER_OTHERS), css::uno::UNO_QUERY);
         {
@@ -1517,7 +1517,7 @@ void FilterCache::impl_load(EFillState e
        )
     {
         // Attention! If config couldnt be opened successfully
         // and exception os thrown automaticly and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xHandlers(impl_openConfig(E_PROVIDER_OTHERS), css::uno::UNO_QUERY);
         {
@@ -1788,7 +1788,7 @@ CacheItem FilterCache::impl_loadItem(con
     throw(css::uno::Exception)
 {
     // try to get an API object, which points directly to the
-    // requested item. If it fail an exception should occure and
+    // requested item. If it fail an exception should occur and
     // break this operation. Of course returned API object must be
     // checked too.
     css::uno::Reference< css::container::XNameAccess > xItem;
@@ -1883,7 +1883,7 @@ CacheItem FilterCache::impl_loadItem(con
                 aItem[PROPNAME_USERDATA    ] = xItem->getByName(PROPNAME_USERDATA    );
                 aItem[PROPNAME_TEMPLATENAME] = xItem->getByName(PROPNAME_TEMPLATENAME);
 //TODO remove it if moving of filter uinames to type uinames
 //       will be finished realy
 #ifdef AS_ENABLE_FILTER_UINAMES
                 impl_readPatchUINames(xItem, aItem);
 #endif // AS_ENABLE_FILTER_UINAMES
@@ -1951,7 +1951,7 @@ CacheItemList::iterator FilterCache::imp
 
         case E_DETECTSERVICE :
         {
-            OSL_ENSURE(sal_False, "Cant load detect services on demand. Who use this unsupported feature?");
+            OSL_ENSURE(sal_False, "Can't load detect services on demand. Who use this unsupported feature?");
         }
         break;
     }
@@ -2068,7 +2068,7 @@ void FilterCache::impl_saveItem(const cs
             }
 
 //TODO remove it if moving of filter uinames to type uinames
 //       will be finished realy
 #ifdef AS_ENABLE_FILTER_UINAMES
             css::uno::Reference< css::container::XNameReplace > xUIName;
             xItem->getByName(PROPNAME_UINAME) >>= xUIName;
@@ -2092,7 +2092,7 @@ void FilterCache::impl_saveItem(const cs
 
 /*-----------------------------------------------
     20.10.2003 09:45
-    static! => no locks neccessary
+    static! => no locks necessary
 -----------------------------------------------*/
 css::uno::Sequence< ::rtl::OUString > FilterCache::impl_convertFlagField2FlagNames(sal_Int32 nFlags)
 {
@@ -2127,7 +2127,7 @@ css::uno::Sequence< ::rtl::OUString > Fi
 
 /*-----------------------------------------------
     27.06.2003 09:26
-    static! => no locks neccessary
+    static! => no locks necessary
 -----------------------------------------------*/
 sal_Int32 FilterCache::impl_convertFlagNames2FlagField(const css::uno::Sequence< ::rtl::OUString >& lNames)
 {
@@ -2338,7 +2338,7 @@ void FilterCache::impl_interpretDataVal4
 /*-----------------------------------------------
     12.02.2004 08:30
     TODO work on a cache copy first, which can be flushed afterwards
-         That would be usefully to gurantee a consistent cache.
+         That would be usefully to guarantee a consistent cache.
 -----------------------------------------------*/
 void FilterCache::impl_readOldFormat()
     throw(css::uno::Exception)
@@ -2347,7 +2347,7 @@ void FilterCache::impl_readOldFormat()
     static ::rtl::OUString FILTER_SET = ::rtl::OUString::createFromAscii("Filters");
 
     // Attention: Opening/Reading of this old configuration format has to be handled gracefully.
     // Its optional and shouldnt disturb our normal work!
     // E.g. we must check, if the package exists ...
 
     css::uno::Reference< css::container::XNameAccess > xCfg;
@@ -2398,14 +2398,14 @@ CacheItem FilterCache::impl_readOldItem(
     xSet->getByName(sItem) >>= xItem;
     if (!xItem.is())
         throw css::uno::Exception(
-                ::rtl::OUString::createFromAscii("Cant read old item."),
+                ::rtl::OUString::createFromAscii("Can't read old item."),
                 css::uno::Reference< css::uno::XInterface >());
 
     CacheItem aItem;
     aItem[PROPNAME_NAME] <<= sItem;
 
     // Installed flag ...
-    // Isnt used any longer!
+    // Isn't used any longer!
 
     // UIName
     impl_readPatchUINames(xItem, aItem);
@@ -2421,7 +2421,7 @@ CacheItem FilterCache::impl_readOldItem(
        )
     {
         throw css::uno::Exception(
-                ::rtl::OUString::createFromAscii("Cant read old item property DATA."),
+                ::rtl::OUString::createFromAscii("Can't read old item property DATA."),
                 css::uno::Reference< css::uno::XInterface >());
     }
 
@@ -429,14 +429,14 @@ CacheItem FilterCache::getItem(      EIt
         // ... or load it on demand from the
         // underlying configuration layer.
-        // Note: NoSuchElementException is thrown automaticly here if
+        // Note: NoSuchElementException is thrown automatically here if
         // item could not be loaded!
         pIt = impl_loadItemOnDemand(eType, sItem);
@@ -1134,8 +1134,8 @@ void FilterCache::impl_validateAndOptimi
         // set it at the end of this optimized list. But if its
         // a "Preferred" one - set it to the front of this list.
-        // Of course multiple "Preferred" registrations can occure
-        // (they shouldnt - but they can!) ... Ignore it. The last
+        // Of course multiple "Preferred" registrations can occur
+        // (they shouldn't - but they can!) ... Ignore it. The last
         // preferred type is useable in the same manner then every
         // other type!
@@ -1176,7 +1176,7 @@ void FilterCache::impl_validateAndOptimi
         // not all filters read from disk!
         // OK - this cache can read single filters on demand too ...
-        // but then the fill state of this cache shouldnt be set to E_CONTAINS_FILTERS!
+        // but then the fill state of this cache shouldn't be set to E_CONTAINS_FILTERS!
         if (!bAllFiltersShouldExist)
             continue;
@@ -1416,7 +1416,7 @@ void FilterCache::impl_resolveItem4TypeR
 {
     CacheItem& rItem = (*pList)[sItem];
-    // In case its a new created entry (automaticly done by the hash_map index operator!)
+    // In case its a new created entry (automatically done by the hash_map index operator!)
     // we must be shure, that this entry has its own name as property available.
     // Its needed later at our container interface!
@@ -1449,7 +1449,7 @@ void FilterCache::impl_load(EFillState e
     {
         // Attention! If config couldnt be opened successfully
-        // and exception os thrown automaticly and must be forwarded
+        // and exception os thrown automatically and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xTypes(impl_openConfig(E_PROVIDER_TYPES), css::uno::UNO_QUERY);
@@ -1466,7 +1466,7 @@ void FilterCache::impl_load(EFillState e
     {
         // Attention! If config couldnt be opened successfully
-        // and exception os thrown automaticly and must be forwarded
+        // and exception os thrown automatically and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xTypes(impl_openConfig(E_PROVIDER_TYPES), css::uno::UNO_QUERY);
@@ -1483,7 +1483,7 @@ void FilterCache::impl_load(EFillState e
     {
         // Attention! If config couldnt be opened successfully
-        // and exception os thrown automaticly and must be forwarded
+        // and exception os thrown automatically and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xFilters(impl_openConfig(E_PROVIDER_FILTERS), css::uno::UNO_QUERY);
@@ -1500,7 +1500,7 @@ void FilterCache::impl_load(EFillState e
     {
         // Attention! If config couldnt be opened successfully
-        // and exception os thrown automaticly and must be forwarded
+        // and exception os thrown automatically and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xLoaders(impl_openConfig(E_PROVIDER_OTHERS), css::uno::UNO_QUERY);
@@ -1517,7 +1517,7 @@ void FilterCache::impl_load(EFillState e
     {
         // Attention! If config couldnt be opened successfully
-        // and exception os thrown automaticly and must be forwarded
+        // and exception os thrown automatically and must be forwarded
         // to our calli ...
         css::uno::Reference< css::container::XNameAccess > xHandlers(impl_openConfig(E_PROVIDER_OTHERS), css::uno::UNO_QUERY);
@@ -1883,7 +1883,7 @@ CacheItem FilterCache::impl_loadItem(con
                 aItem[PROPNAME_TEMPLATENAME] = xItem->getByName(PROPNAME_TEMPLATENAME);
 //TODO remove it if moving of filter uinames to type uinames
-//       will be finished realy
+//       will be finished really
 #ifdef AS_ENABLE_FILTER_UINAMES
                 impl_readPatchUINames(xItem, aItem);
@@ -2068,7 +2068,7 @@ void FilterCache::impl_saveItem(const cs
 
 //TODO remove it if moving of filter uinames to type uinames
-//       will be finished realy
+//       will be finished really
 #ifdef AS_ENABLE_FILTER_UINAMES
             css::uno::Reference< css::container::XNameReplace > xUIName;
@@ -2347,7 +2347,7 @@ void FilterCache::impl_readOldFormat()
 
     // Attention: Opening/Reading of this old configuration format has to be handled gracefully.
-    // Its optional and shouldnt disturb our normal work!
+    // Its optional and shouldn't disturb our normal work!
     // E.g. we must check, if the package exists ...
 

Modified: openoffice/trunk/main/filter/source/config/cache/filtercache.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/filtercache.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/config/cache/filtercache.hxx (original)
+++ openoffice/trunk/main/filter/source/config/cache/filtercache.hxx Tue Apr 29 19:05:05 2014
@@ -153,7 +153,7 @@ class FilterCache : public BaseLock
          */
         enum EItemFlushState
         {
             /// indicates an unchanged item (can occure e.g. if an item was added and(!) removed before it was flushed ...
             E_ITEM_UNCHANGED = 0,
             /// indicates an item, which exists inside config layer but not inside our own cache
             E_ITEM_REMOVED = 1,
@@ -281,7 +281,7 @@ class FilterCache : public BaseLock
         /** @short  standard ctor
 
             @descr  Its not allowed to do anything here ...
-                    especialy is forbidden to start operations,
+                    especially is forbidden to start operations,
                     which needs a FilterCache instance too!
                     Why? Because thie FilterCache instance will be
                     used as a singleton! And if during this ctor any
@@ -309,12 +309,12 @@ class FilterCache : public BaseLock
                     After its changed data was flushed to the configuration it can be
                     removed.
 
-                    The original container will get these new data automaticly
+                    The original container will get these new data automatically
                     because it listen for changes on the internal used configuration layer.
-                    If the new data are needed immediatly inside the original container,
+                    If the new data are needed immediately inside the original container,
                     the method takeOver() can be used to copy all changes back.
                     The may be following notifications of the configuration will be superflous then.
-                    But they cant be stopped ...
+                    But they can't be stopped ...
 
                     All internal structures will be copied here. But the internal used
                     configuration (update) access wont be copied. The cloned instance contains
@@ -348,7 +348,7 @@ class FilterCache : public BaseLock
                         if this "load-on-demand" thread does not finished its work before.
                         This method "load(xxx)" synchronize such load-on-demand requests.
 
-                        Of course it would be possible to supress this special load thread
+                        Of course it would be possible to suppress this special load thread
                         in general and start it manualy inside this load() request.
                         The outside code decide then, if and when this cache will be filled
                         with all available informations ...
@@ -361,7 +361,7 @@ class FilterCache : public BaseLock
                         "load-on-demand-thread", which tries to optimize our startup performance
                         and start this load() only in case the office startup was already finished!
 
-            @throw      An exception if the cache could not be filled realy
+            @throw      An exception if the cache could not be filled really
                         or seems to be invalid afterwards. But there is no reaction
                         at all if this method does nothing inside, because the cache
                         is already full filled!
@@ -482,7 +482,7 @@ class FilterCache : public BaseLock
             @attention  This method exists to supports some UNO container interfaces
                         only. (e.g. XNameAccess.hasByName()). But inside multithreaded
                         environments there is no guarantee, that this item still exists, if
-                        its realy requested e.g. by calling getItem()!
+                        its really requested e.g. by calling getItem()!
                         Be aware of some NoSuchElementExistExceptions ...
 
             @param      eType
@@ -505,7 +505,7 @@ class FilterCache : public BaseLock
         /** @short      return an item, which match the specified type and name.
 
             @descr      Because this cache can be used inside multithreaded environments
-                        the caller must be aware of some exceptions - especialy a "NoSuchElementExcepotion".
+                        the caller must be aware of some exceptions - especially a "NoSuchElementExcepotion".
                         May another thread already removed the required item before ...
 
             @param      eType
@@ -561,7 +561,7 @@ class FilterCache : public BaseLock
                         cache item reference.
 
             @descr      Such properties can e.g. finalized or mandatory.
-                        They are not persistent  and not realy part of e.g. a
+                        They are not persistent  and not really part of e.g. a
                         filter not. But they are attributes of a configuration
                         entry and can influence our container interface.
 
@@ -584,12 +584,12 @@ class FilterCache : public BaseLock
                         attributes there.
 
             @throw      [css::uno::Exception]
-                        if an internal error occured.
+                        if an internal error occurred.
                         Note: If the item is missing inside the underlying configuration
                         no exception will be thrown. In such case the item is marked as
-                        finalized/mandatory automaticly
+                        finalized/mandatory automatically
                         Reason: May be the item cames from the old configuration package and
-                        was not migrated to the new one. So we cant provide write access
+                        was not migrated to the new one. So we can't provide write access
                         to such items ...
          */
         virtual void addStatePropsToItem(      EItemType        eType,
@@ -628,7 +628,7 @@ class FilterCache : public BaseLock
 
             @param      aURL
                         URL of the content, which type should be detected.
-                        Its already parsed and splitted into its differnt parts,
+                        Its already parsed and splitted into its different parts,
                         like e.g.: main, jump marks etcpp.
 
             @param      rFlatTypes
@@ -689,7 +689,7 @@ class FilterCache : public BaseLock
                         see EConfigProvider for further informations ...
 
             @attention  If a configuration access was opened successfully
-                        all neccessary listener connections will be established
+                        all necessary listener connections will be established
                         too. So this cache will be informed about outside updates.
          */
         css::uno::Reference< css::uno::XInterface > impl_openConfig(EConfigProvider eProvide)
@@ -737,7 +737,7 @@ class FilterCache : public BaseLock
 
             @return     [css::uno::Any]
                         the value of the requested key.
-                        Can be empty if an internal error occured or if the requested
+                        Can be empty if an internal error occurred or if the requested
                         key does not exists!
          */
         css::uno::Any impl_getDirectCFGValue(const ::rtl::OUString& sDirectKey);
@@ -762,8 +762,8 @@ class FilterCache : public BaseLock
         /** @short      validate the whole cache and create
                         structures for optimized items access.
 
-            @descr      Wrong cache items will be removed automaticly.
-                        Wrong dependencies will be corrected automaticly.
+            @descr      Wrong cache items will be removed automatically.
+                        Wrong dependencies will be corrected automatically.
                         If something could not be repaired - an exception
                         is thrown.
                         Further some optmized structures will be created.
@@ -783,9 +783,9 @@ class FilterCache : public BaseLock
         /** @short      register the specified item for the given type.
 
             @descr      Because detect services, frame loader or content handler
-                        are not listed inside the xml configuration as seperated
+                        are not listed inside the xml configuration as separated
                         items (they are properties of any type entry!), this method update
-                        the internal lists of such items. Thats neccessary to have
+                        the internal lists of such items. Thats necessary to have
                         it accessible for our container interfaces of detect, frame loader
                         and content handler services.
 
@@ -839,7 +839,7 @@ class FilterCache : public BaseLock
                     points to the cache member, which should be filled or updated.
 
             @throw  [css::uno::Exception]
-                    if an unrecoverable error occure inside this operation.
+                    if an unrecoverable error occur inside this operation.
          */
         void impl_loadSet(const css::uno::Reference< css::container::XNameAccess >& xConfig,
                                 EItemType                                           eType  ,
@@ -861,15 +861,15 @@ class FilterCache : public BaseLock
                     specify, which container item type must be readed.
 
             @param  sItem
-                    means the internal name, which can be used to adress the item
+                    means the internal name, which can be used to address the item
                     properties relativ to the given configuration set.
 
             @param  eOption
                     regulate, which properties of the requested item should be read.
-                    See defintion of EReadOption for further informations.
+                    See definition of EReadOption for further informations.
 
             @throw  [css::uno::Exception]
-                    if an unrecoverable error occure inside this operation.
+                    if an unrecoverable error occur inside this operation.
          */
         CacheItem impl_loadItem(const css::uno::Reference< css::container::XNameAccess >& xSet   ,
                                       EItemType                                           eType  ,
@@ -884,7 +884,7 @@ class FilterCache : public BaseLock
 
             @descr  The outside code has to be shure, that the item does not already exists
                     inside this cachse. Otherwise it will be loaded twice. This method
-                    doesnt check such constellations!
+                    doesn't check such constellations!
 
             @param  eType
                     specify the type of config item, which must be interpreted.
@@ -895,14 +895,14 @@ class FilterCache : public BaseLock
                     the set node name of the requested item.
 
             @return An iterator, which points directly to the new cached item.
-                    Is a valid iterator if no exception occured here!
+                    Is a valid iterator if no exception occurred here!
                     But to improve robustness - it should be checked :-)
 
             @throw  [css::container::NoSuchElementException]
                     if the item does not exists inside the configuration layer too!
 
             @throw  [css::uno::Exception]
-                    if an unrecoverable error occure inside this operation.
+                    if an unrecoverable error occurs inside this operation.
          */
         CacheItemList::iterator impl_loadItemOnDemand(      EItemType        eType,
                                                       const ::rtl::OUString& sItem)
@@ -935,7 +935,7 @@ class FilterCache : public BaseLock
 
         //---------------------------------------
 
         /** @short  specify, which save operation is neccessary for the specified item.
 
             @desrc  If an item of this cache will be added/removed or modified it will
                     be changed inside memory only first. But we save its name inside a special
@@ -153,7 +153,7 @@ class FilterCache : public BaseLock
         enum EItemFlushState
         {
-            /// indicates an unchanged item (can occure e.g. if an item was added and(!) removed before it was flushed ...
+            /// indicates an unchanged item (can occur e.g. if an item was added and(!) removed before it was flushed ...
             E_ITEM_UNCHANGED = 0,
             /// indicates an item, which exists inside config layer but not inside our own cache
@@ -935,7 +935,7 @@ class FilterCache : public BaseLock
         //---------------------------------------
 
-        /** @short  specify, which save operation is neccessary for the specified item.
+        /** @short  specify, which save operation is necessary for the specified item.
 
             @desrc  If an item of this cache will be added/removed or modified it will

Modified: openoffice/trunk/main/filter/source/config/cache/filterfactory.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/config/cache/filterfactory.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================